(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[383],{4305:function(e,s,a){Promise.resolve().then(a.bind(a,24e3))},24e3:function(e,s,a){"use strict";a.r(s),a.d(s,{default:function(){return PlaygroundPage},dynamic:function(){return u}});var n=a(57437),t=a(71340),l=a(2265),i=a(46816),o=a(91611),r=a(23774),c=a(80105);a(99176);var d=a(43574);let x={agent:function(e){let{data:s,isConnectable:a}=e;return(0,l.useCallback)(e=>{console.log(e.target.value)},[]),(0,n.jsxs)("div",{className:"font-light border-green    text-md border  rounded bg-white",children:[(0,n.jsx)(i.HH,{type:"target",position:i.Ly.Top,isConnectable:a}),(0,n.jsx)("div",{className:"p-2 capitalize   border-b",children:(0,n.jsxs)("span",{className:"capitalize",children:[" ",s.label||"Agent"]})}),(0,n.jsx)("div",{className:"p-2 ",children:(0,n.jsxs)("div",{className:"flex",children:[(0,n.jsx)("label",{className:"mr-2",htmlFor:"name",children:"Name"}),(0,n.jsx)(d.Z,{className:"inline-block nodrag",placeholder:"Basic usage"})]})}),(0,n.jsx)(i.HH,{type:"source",position:i.Ly.Bottom,id:"b",isConnectable:a})]})},chat:function(e){let{data:s,isConnectable:a}=e;return(0,l.useCallback)(e=>{console.log(e.target.value)},[]),(0,n.jsxs)("div",{style:{minHeight:"300px"},className:"font-light border-green    text-md border  rounded bg-white",children:[(0,n.jsx)(i.HH,{type:"target",position:i.Ly.Left,isConnectable:a}),(0,n.jsx)(i.HH,{type:"target",position:i.Ly.Top,isConnectable:a}),(0,n.jsx)("div",{className:"p-2 capitalize   border-b",children:(0,n.jsxs)("span",{className:"capitalize",children:[" ",s.label||"Agent"]})}),(0,n.jsx)("div",{className:"p-2 ",children:(0,n.jsxs)("div",{className:"flex",children:[(0,n.jsx)("label",{className:"mr-2",htmlFor:"name",children:"Name"}),(0,n.jsx)(d.Z,{className:"inline-block nodrag",placeholder:"Basic usage"})]})}),(0,n.jsx)(i.HH,{type:"source",position:i.Ly.Bottom,id:"b",isConnectable:a})]})}};function FlowView(){let[e,s,a]=(0,i.Rr)([{id:"1",position:{x:0,y:0},data:{label:"User Proxy"},type:"agent"},{id:"3",position:{x:300,y:130},data:{label:"Assistant"},type:"agent"},{id:"4",position:{x:700,y:130},data:{label:"Output"},type:"chat"}]),[t,d,u]=(0,i.ll)([{id:"e1-3",source:"1",target:"3"}]),h=(0,l.useCallback)(e=>d(s=>(0,i.Z_)(e,s)),[d]);return(0,n.jsx)("div",{className:"border rounded p-2",children:(0,n.jsx)("div",{style:{width:"100%",height:"calc(100vh - 180px"},children:(0,n.jsxs)(i.x$,{nodes:e,edges:t,onNodesChange:a,onEdgesChange:u,onConnect:h,nodeTypes:x,children:[(0,n.jsx)(o.Z,{}),(0,n.jsx)(r.a,{}),(0,n.jsx)(c.A,{variant:c.T.Dots,gap:12,size:1})]})})})}let u="force-static";function PlaygroundPage(){return(0,n.jsxs)("div",{className:"text-md  ",children:[(0,n.jsx)(t.Z,{className:"mb-2",children:"Playground"}),(0,n.jsx)("div",{children:(0,n.jsx)(FlowView,{})})]})}}},function(e){e.O(0,[780,900,980,971,472,744],function(){return e(e.s=4305)}),_N_E=e.O()}]);