# a manager class that can
# load an autogen flow run an autogen flow and return the response to the client


from typing import Dict
import autogen


class Flow(object):
    def __init__(self) -> None:

        pass

    def run(self, llm_config:):